@@ -7,7 +7,7 @@ import hildon
 from os import listdir, path, system
 from ConfigParser import SafeConfigParser
 
-version = "1.6-1"
+version = "1.6-2"
 trackingEnabled = True
 stopTracking = True
 stopWhenIdle = False
@@ -22,6 +22,7 @@ keepWifiPMOff = False
 toggleWifiPM = False
 wifiPMOffSec = "2 seconds"
 wifiPMOnSec = "4 seconds"
+configReverseOrder = False
 
 class Main(object):
     def __init__(self):
@@ -39,6 +40,7 @@ class Main(object):
         global toggleWifiPM
         global wifiPMOffSec
         global wifiPMOnSec
+        global configReverseOrder
         
         autostartDisabled = False
         keepWifiPMOffInstalled = False
@@ -66,6 +68,7 @@ class Main(object):
             self.parser.set('options', 'showConnected', str(showConnected))
             self.parser.set('options', 'connectedIcon', str(connectedIcon))
             self.parser.set('options', 'skipSystemCheck', str(skipSystemCheck))
+            self.parser.set('options', 'configReverseOrder', str(skipSystemCheck))
             self.parser.write(configFile)
             configFile.close()
         else:
@@ -107,6 +110,10 @@ class Main(object):
                     skipSystemCheck = self.parser.getboolean('options', 'skipSystemCheck')
                 else:
                     self.parser.set('options', 'skipSystemCheck', str(skipSystemCheck))
+                if self.parser.has_option('options', 'configReverseOrder'):
+                    configReverseOrder = self.parser.getboolean('options', 'configReverseOrder')
+                else:
+                    self.parser.set('options', 'configReverseOrder', str(configReverseOrder))
         
         if not path.isfile("/etc/event.d/sshd"):
             system("sudo /usr/sbin/openssh-status.sh create_sshd")
@@ -179,8 +186,8 @@ class Main(object):
         window.set_title("OpenSSH Status Widget")
         window.connect("delete_event", gtk.main_quit, None)
         
-        labelWidget = gtk.Label("Widget options:")
-        labelOther = gtk.Label("Server options:")
+        self.labelWidget = gtk.Label("Widget options:")
+        self.labelServer = gtk.Label("Server options:")
     
         self.buttonTrackingEnabled = hildon.CheckButton(gtk.HILDON_SIZE_FULLSCREEN_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT)
         self.buttonTrackingEnabled.set_label("Enable tracking")
@@ -249,26 +256,18 @@ class Main(object):
     
         vboxBorder = gtk.VBox(False, 0)
         vboxBorder.set_border_width(8)
-        vbox = gtk.VBox(False, 0)
-        vbox.set_border_width(0)
-        vbox.pack_start(labelWidget, False, False, 8)
-        vbox.pack_start(self.buttonTrackingEnabled, False, False, 0)
-        vbox.pack_start(self.buttonStopTracking, False, False, 0)
-        vbox.pack_start(self.buttonStopWhenIdle, False, False, 0)
-        vbox.pack_start(self.buttonStopAfterMinutes, False, False, 0)
-        vbox.pack_start(self.buttonConfirm, False, False, 0)
-        vbox.pack_start(self.buttonShowRestart, False, False, 0)
-        vbox.pack_start(self.buttonShowConnected, False, False, 0)
-        vbox.pack_start(self.buttonConnectedIcon, False, False, 0)
-        vbox.pack_start(labelOther, False, False, 8)
-        vbox.pack_start(self.buttonAutostart, False, False, 0)
-        vbox.pack_start(self.buttonKeepWifiPMOff, False, False, 0)
-        vbox.pack_start(self.buttonToggleWifiPM, False, False, 0)
-        vbox.pack_start(self.buttonWifiPMOffSec, False, False, 0)
-        vbox.pack_start(self.buttonWifiPMOnSec, False, False, 0)
+        self.vbox = gtk.VBox(False, 0)
+        self.vbox.set_border_width(0)
+        
+        if configReverseOrder:
+            self.pack_startServerButtons()
+            self.pack_startWidgetButtons()
+        else:
+            self.pack_startWidgetButtons()
+            self.pack_startServerButtons()
         
         areaScrolling = hildon.PannableArea()
-        areaScrolling.add_with_viewport(vbox)
+        areaScrolling.add_with_viewport(self.vbox)
         areaScrolling.set_border_width(0)
         
         vboxBorder.pack_start(areaScrolling, True, True, 0)
@@ -360,6 +359,44 @@ class Main(object):
     
         gtk.main()
         
+    def pack_startWidgetButtons(self):
+        self.vbox.pack_start(self.labelWidget, False, False, 8)
+        self.vbox.pack_start(self.buttonTrackingEnabled, False, False, 0)
+        self.vbox.pack_start(self.buttonStopTracking, False, False, 0)
+        self.vbox.pack_start(self.buttonStopWhenIdle, False, False, 0)
+        self.vbox.pack_start(self.buttonStopAfterMinutes, False, False, 0)
+        self.vbox.pack_start(self.buttonConfirm, False, False, 0)
+        self.vbox.pack_start(self.buttonShowRestart, False, False, 0)
+        self.vbox.pack_start(self.buttonShowConnected, False, False, 0)
+        self.vbox.pack_start(self.buttonConnectedIcon, False, False, 0)
+    
+    def pack_startServerButtons(self):
+        self.vbox.pack_start(self.labelServer, False, False, 8)
+        self.vbox.pack_start(self.buttonAutostart, False, False, 0)
+        self.vbox.pack_start(self.buttonKeepWifiPMOff, False, False, 0)
+        self.vbox.pack_start(self.buttonToggleWifiPM, False, False, 0)
+        self.vbox.pack_start(self.buttonWifiPMOffSec, False, False, 0)
+        self.vbox.pack_start(self.buttonWifiPMOnSec, False, False, 0)
+        
+    def removeWidgetButtons(self):
+        self.vbox.remove(self.labelWidget)
+        self.vbox.remove(self.buttonTrackingEnabled)
+        self.vbox.remove(self.buttonStopTracking)
+        self.vbox.remove(self.buttonStopWhenIdle)
+        self.vbox.remove(self.buttonStopAfterMinutes)
+        self.vbox.remove(self.buttonConfirm)
+        self.vbox.remove(self.buttonShowRestart)
+        self.vbox.remove(self.buttonShowConnected)
+        self.vbox.remove(self.buttonConnectedIcon)
+    
+    def removeServerButtons(self):
+        self.vbox.remove(self.labelServer)
+        self.vbox.remove(self.buttonAutostart)
+        self.vbox.remove(self.buttonKeepWifiPMOff)
+        self.vbox.remove(self.buttonToggleWifiPM)
+        self.vbox.remove(self.buttonWifiPMOffSec)
+        self.vbox.remove(self.buttonWifiPMOnSec)
+        
     def buttonTrackingEnabled_clicked(self, dummy):
         global trackingEnabled
         trackingEnabled = not trackingEnabled
@@ -512,13 +549,17 @@ class Main(object):
         menu = hildon.AppMenu()
     
         buttonRestart = hildon.GtkButton(gtk.HILDON_SIZE_AUTO)
-        buttonRestart.set_label('Restart Status Menu')
+        buttonRestart.set_label('Restart status menu')
         buttonRestart.connect("clicked", self.restart_clicked)
+        buttonReverse = hildon.GtkButton(gtk.HILDON_SIZE_AUTO)
+        buttonReverse.set_label('Reverse sections order')
+        buttonReverse.connect("clicked", self.reverse_clicked)
         buttonAbout = hildon.GtkButton(gtk.HILDON_SIZE_AUTO)
         buttonAbout.set_label('About')
         buttonAbout.connect("clicked", self.about_clicked)
     
         menu.append(buttonRestart)
+        menu.append(buttonReverse)
         menu.append(buttonAbout)
     
         menu.show_all()
@@ -527,7 +568,18 @@ class Main(object):
     
     def restart_clicked(self, dummy):
         system("killall hildon-status-menu")
-        return
+        
+    def reverse_clicked(self, dummy):
+        global configReverseOrder
+        configReverseOrder = not configReverseOrder
+        if configReverseOrder:
+            self.removeWidgetButtons()
+            self.pack_startWidgetButtons()
+        else:
+            self.removeServerButtons()
+            self.pack_startServerButtons()
+        self.parser.set('options', 'configReverseOrder', str(configReverseOrder))
+        self.write_config()
     
     def about_clicked(self, dummy):
         self.about = gtk.Dialog("About", None)
