@@ -7,10 +7,14 @@ import hildon
 import time
 import dbus
 from dbus.mainloop.glib import DBusGMainLoop
-from os import path, system
+from os import path, remove, system
 from commands import getoutput
 from ConfigParser import SafeConfigParser
 
+try:
+    remove("/home/user/.openssh-status-connected")
+except:
+    print("")
 
 class opensshStatus(hildondesktop.StatusMenuItem):
     def __init__(self):
@@ -20,7 +24,6 @@ class opensshStatus(hildondesktop.StatusMenuItem):
         self.stopTracking = True
         self.stopWhenIdle = False
         self.stopAfterMinutes = 5
-        self.keepWifiPMOff = True
         self.confirmDisconnect = True
         self.showRestartButton = False
         self.showConnected = True
@@ -40,9 +43,7 @@ class opensshStatus(hildondesktop.StatusMenuItem):
             if parser.has_option('options', 'stopWhenIdle'):
                 self.stopWhenIdle = parser.getboolean('options', 'stopWhenIdle')
             if parser.has_option('options', 'stopAfterMinutes'):
-                self.stopAfterMinutes = int(parser.get('options', 'stopAfterMinutes').split()[0])
-            if parser.has_option('options', 'keepWifiPMOff'):
-                self.keepWifiPMOff = parser.getboolean('options', 'keepWifiPMOff')
+                self.stopAfterMinutes = int(parser.get('options', 'stopAfterMinutes').strip('_').split()[0]) # fix changed syntax when updating from < v1.6-0
             if parser.has_option('options', 'confirmDisconnect'):
                 self.confirmDisconnect = parser.getboolean('options', 'confirmDisconnect')
             if parser.has_option('options', 'showRestartButton'):
@@ -268,20 +269,23 @@ class opensshStatus(hildondesktop.StatusMenuItem):
                         self.sshJustOff = 0
                         self.refresh = False
                         self.waitWhileIdle = False
-                        if self.keepWifiPMOff:
-                            self.refreshWifiPMOff = False
-                            system("sudo /usr/sbin/openssh-status.sh enable_wifipm")
-                            if self.wifiTX10:
-                                system("sudo /usr/sbin/openssh-status.sh switch_wifitx")
                         return False
                 else:
                     return True
             # Stop server when not connected
             if not self.sshConnected and self.stopWhenIdle:
                 if not self.waitWhileIdle:
+                    try:
+                        remove("/home/user/.openssh-status-connected")
+                    except:
+                        self.waitWhileIdle = True
                     self.idleStartTime = time.time()
                     self.waitWhileIdle = True
                     return True
+                elif self.loops and path.isfile("/home/user/.openssh-status-connected"):
+                    remove("/home/user/.openssh-status-connected")
+                    self.idleStartTime = time.time()
+                    return True
                 elif time.time() - self.idleStartTime + 5 > self.stopAfterMinutes * 60:
                     system("sudo /usr/sbin/openssh-status.sh stop_sshd")
                     time.sleep(1)
